==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/cabin2/dialogs_es.lua <==

dialogId("k1-pap-3xkruty", "font_parrot", "Crrruel, crrruel, crrruel Captain Silverrrr...")
dialogStr("Crrueeel, crrueeel, crueeel Capitán Silverrrr...")


dialogId("k1-pap-kruty", "font_parrot", "Crrruel Captain Silverrrr...")
dialogStr("Crrueeel Capitán Silverrr...")


dialogId("k1-pap-kruci", "font_parrot", "Good grrrief!")
dialogStr("¡Buen prrrrobleeema!")


dialogId("k1-pap-problem", "font_parrot", "Trrricky prrroblem, isn`t it?")
dialogStr("Complicaaaado prrrrobleeeema, ¿cierrrrto?")


dialogId("k1-pap-sakris", "font_parrot", "Darrrn!")
dialogStr("¡Desdichaaa!")


dialogId("k1-pap-sucharek", "font_parrot", "Polly wants a crrracker!")
dialogStr("¡Polly quiere un petarrrdo!")


dialogId("k1-pap-trhnisi", "font_parrot", "Beat it, sirrr...")
dialogStr("Golpéelo, señorrr...")


dialogId("ka2-v-nekde", "font_big", "Didn`t we see this somewhere already?")
dialogStr("¿No habíamos visto ya esto en otro lugar?")


dialogId("ka2-m-kdepak", "font_small", "No, you`re wrong. This cabin is one hundred and forty four squares larger...")
dialogStr("No, estás equivocado. Esta cabina es ciento cuarenta y cuatro cuadros más larga...")


dialogId("ka2-v-papousek", "font_big", "Look at that parrot!!!")
dialogStr("¡Mira ese loro!!!")


dialogId("ka2-m-kostra", "font_small", "So what? It's a normal skeleton.")
dialogStr("¿Qué tiene? Es un esqueleto normal.")


dialogId("ka2-m-posledni", "font_small", "Can you see it? This room is almost the last in the row. Could this really be that treasure?")
dialogStr("¿Puedes verlo? Esta habitación es casi la última. ¿Podría ésta ser realmente la del tesoro?")


dialogId("ka2-v-mapa0", "font_big", "And what would be in the other two?")
dialogStr("¿Y qué podría haber en los otros dos?")


dialogId("ka2-v-mapa1", "font_big", "They told us clearly to find the map. Nobody mentioned treasure.")
dialogStr("Nos dijeron claramente que encontráramos el mapa. Nadie habló de tesoro.")


dialogId("ka2-v-mapa2", "font_big", "Don`t be so annoying. The authors of the game would surely let the player know.")
dialogStr("No seas tan irritante. Los autores del juego seguramente dejarán que el jugador sepa.")


dialogId("ka2-m-chapadlo", "font_small", "This octopus has unpleasantly knotted tentacles. I can`t fit between them.")
dialogStr("Este pulpo tiene unos desagradables tentáculos anudados. Yo no puedo caber entre ellos.")


dialogId("ka2-v-fik", "font_big", "... so what if we cut one off?!")
dialogStr("... ¡¿y que tal si le cortamos uno?!")


dialogId("ka2-v-napad", "font_big", "I am sorry, it was just an idea.")
dialogStr("Lo siento, fué sólo una idea.")


dialogId("ka2-m-hej", "font_small", "Little octopus, couldn`t you move away a little bit, please?")
dialogStr("Pequeño pulpo, ¿puedes apartarte un poquito, por favor?")


dialogId("ka2-m-diky", "font_small", "Hmm... thanks a lot.")
dialogStr("Hmm... muchas gracias.")


dialogId("ka2-v-kostry", "font_big", "Skeletons seem to be a favorite motif of this game authors.")
dialogStr("Los esqueletos parecen ser el motivo favorito de los autores de este juego.")


dialogId("ka2-m-patrne", "font_small", "Who are probably living on land. These skeletons are visible proof of their effort to stuff the ocean with all the things that don`t belong there.")
dialogStr("Quienes están probablemente viviendo en tierra. Esos esqueletos son la prueba visible de su esfuerzo para llenar el océano con todas las cosas que no pertenecen ahí.")


dialogId("ka2-v-myslet", "font_big", "Let`s try to think. Can`t we take our solution of that previous cabin and modify it a little?")
dialogStr("Tratemos de pensar. ¿Podemos tomar nuestra solución de esa cabina previa y modificarla un poquito?")


dialogId("ka2-m-tezko", "font_small", "Hmm... I don`t think so.")
dialogStr("Hmm... No lo creo.")


dialogId("ka2-m-svitit", "font_small", "So, let`s shed some light on it.")
dialogStr("Asi pues, pongamos un poco de luz a esto.")


dialogId("ka2-v-hrbet", "font_big", "My back aches.")
dialogStr("Mi espalda me duele.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/cabin2/dialogs_es.lua <==

dialogId("k1-pap-3xkruty", "font_parrot", "Crrruel, crrruel, crrruel Captain Silverrrr...")
dialogStr("Crrueeel, crrueeel, crueeel Capitán Silverrrr...")


dialogId("k1-pap-kruty", "font_parrot", "Crrruel Captain Silverrrr...")
dialogStr("Crrueeel Capitán Silverrr...")


dialogId("k1-pap-kruci", "font_parrot", "Good grrrief!")
dialogStr("¡Buen prrrrobleeema!")


dialogId("k1-pap-problem", "font_parrot", "Trrricky prrroblem, isn’t it?")
dialogStr("Complicaaaado prrrrobleeeema, ¿cierrrrto?")


dialogId("k1-pap-sakris", "font_parrot", "Darrrn!")
dialogStr("¡Desdichaaa!")


dialogId("k1-pap-sucharek", "font_parrot", "Polly wants a crrracker!")
dialogStr("¡Polly quiere un petarrrdo!")


dialogId("k1-pap-trhnisi", "font_parrot", "Beat it, sirrr...")
dialogStr("Golpéelo, señorrr...")


dialogId("ka2-v-nekde", "font_big", "Didn’t we see this somewhere already?")
dialogStr("¿No habíamos visto ya esto en otro lugar?")


dialogId("ka2-m-kdepak", "font_small", "No, you’re wrong. This cabin is one hundred and forty four squares larger...")
dialogStr("No, estás equivocado. Esta cabina es ciento cuarenta y cuatro cuadros más larga...")


dialogId("ka2-v-papousek", "font_big", "Look at that parrot!!!")
dialogStr("¡Mira ese loro!!!")


dialogId("ka2-m-kostra", "font_small", "So what? It's a normal skeleton.")
dialogStr("¿Qué tiene? Es un esqueleto normal.")


dialogId("ka2-m-posledni", "font_small", "Can you see it? This room is almost the last in the row. Could this really be that treasure?")
dialogStr("¿Puedes verlo? Esta habitación es casi la última. ¿Podría ésta ser realmente la del tesoro?")


dialogId("ka2-v-mapa0", "font_big", "And what would be in the other two?")
dialogStr("¿Y qué podría haber en los otros dos?")


dialogId("ka2-v-mapa1", "font_big", "They told us clearly to find the map. Nobody mentioned treasure.")
dialogStr("Nos dijeron claramente que encontráramos el mapa. Nadie habló de tesoro.")


dialogId("ka2-v-mapa2", "font_big", "Don’t be so annoying. The authors of the game would surely let the player know.")
dialogStr("No seas tan irritante. Los autores del juego seguramente dejarán que el jugador sepa.")


dialogId("ka2-m-chapadlo", "font_small", "This octopus has unpleasantly knotted tentacles. I can’t fit between them.")
dialogStr("Este pulpo tiene unos desagradables tentáculos anudados. Yo no puedo caber entre ellos.")


dialogId("ka2-v-fik", "font_big", "... so what if we cut one off?!")
dialogStr("... ¡¿y que tal si le cortamos uno?!")


dialogId("ka2-v-napad", "font_big", "I am sorry, it was just an idea.")
dialogStr("Lo siento, fué sólo una idea.")


dialogId("ka2-m-hej", "font_small", "Little octopus, couldn’t you move away a little bit, please?")
dialogStr("Pequeño pulpo, ¿puedes apartarte un poquito, por favor?")


dialogId("ka2-m-diky", "font_small", "Hmm... thanks a lot.")
dialogStr("Hmm... muchas gracias.")


dialogId("ka2-v-kostry", "font_big", "Skeletons seem to be a favorite motif of this game authors.")
dialogStr("Los esqueletos parecen ser el motivo favorito de los autores de este juego.")


dialogId("ka2-m-patrne", "font_small", "Who are probably living on land. These skeletons are visible proof of their effort to stuff the ocean with all the things that don’t belong there.")
dialogStr("Quienes están probablemente viviendo en tierra. Esos esqueletos son la prueba visible de su esfuerzo para llenar el océano con todas las cosas que no pertenecen ahí.")


dialogId("ka2-v-myslet", "font_big", "Let’s try to think. Can’t we take our solution of that previous cabin and modify it a little?")
dialogStr("Tratemos de pensar. ¿Podemos tomar nuestra solución de esa cabina previa y modificarla un poquito?")


dialogId("ka2-m-tezko", "font_small", "Hmm... I don’t think so.")
dialogStr("Hmm... No lo creo.")


dialogId("ka2-m-svitit", "font_small", "So, let’s shed some light on it.")
dialogStr("Asi pues, pongamos un poco de luz a esto.")


dialogId("ka2-v-hrbet", "font_big", "My back aches.")
dialogStr("Mi espalda me duele.")
